




******

From the Desk of Mr. Readme:

Bravo!  You have received a Medical Diploma from   
the Orbital Convergence University International Air 
and Water Embassy of the Rust Planet.  

You are now officially certified to include this 
treasure in your practice.

Encore!

******


# wedding

---

## summary
		
		
---		
		
## obtain (install)
```
pip install wedding
```

## on
```
wedding adventures on
```